alDenteLong method
alDente functions roll until condition is set true TODO control: catch the loops inside both functions and make these run parallel / aSync & 'long' logic
Implementation
void alDenteLong(var firstFunction, var secondFunction, bool conduct) {
/// WORD: conduct: finish lang: käytös, menettelytapa, hoito, johto
bool _conduct = conduct;
num _rollCount = 0;
do {
_rollCount++;
firstFunction(); // make bool return values
secondFunction();
// planned 'long' functionality code comes here
// isolateFuncOne() // roll inside isolate or aSync
// isolateFuncTwo()
if (_rollCount == 4) (_conduct = true); // Backdoor
} while (!_conduct); // Not-conduct. Logic?
}